Module geometry

Module geometry 

Utilities for building geometric shapes on a grid.

Structs

GridCircle
A filled circle of points on a 2d grid.
GridCircleOutline
A hollow circle of points on a 2d grid.
GridCone
A cone/triangle of points on a 2d grid.
GridDiamond
A diamond of points on a 2d grid.
GridLine
A line of points on a 2d grid.
GridLineOrtho
An orthogonal line of points on a grid.
GridRect
A rectangle of points on a 2d grid.

Enums

GridShapeIterator

Traits

GridShape
A trait for accessing the points of shapes on a grid.
PositionedGrid
A rectangular grid with a defined size and world position.
SizedGrid
A rectangular grid with a defined size.