GridShape

Trait GridShape 

pub trait GridShape:
    ShapeClone
    + Sync
    + Send
    + 'static {
    // Required methods
    fn iter(&self) -> GridShapeIterator ;
    fn pos(&self) -> IVec2;
    fn set_pos(&mut self, pos: IVec2);
    fn bounds(&self) -> GridRect;
}
A trait for accessing the points of shapes on a grid.

Required Methods

fn iter(&self) -> GridShapeIterator

Iterate over all the points contained within the grid shape.

fn pos(&self) -> IVec2

The position of the grid shape.

fn set_pos(&mut self, pos: IVec2)

Set the position of the grid shape without changing it’s size.

fn bounds(&self) -> GridRect

Get a rect encompassing the entire shape.