Utilities for building geometric shapes on a grid.
Structs
- Grid
Circle - A filled circle of points on a 2d grid.
- Grid
Circle Outline - A hollow circle of points on a 2d grid.
- Grid
Cone - A cone/triangle of points on a 2d grid.
- Grid
Diamond - A diamond of points on a 2d grid.
- Grid
Line - A line of points on a 2d grid.
- Grid
Line Ortho - An orthogonal line of points on a grid.
- Grid
Rect - A rectangle of points on a 2d grid.
Enums
Traits
- Grid
Shape - A trait for accessing the points of shapes on a grid.
- Positioned
Grid - A rectangular grid with a defined size and world position.
- Sized
Grid - A rectangular grid with a defined size.