pub trait GridShape:
ShapeClone
+ Sync
+ Send
+ 'static {
// Required methods
fn iter(&self) -> GridShapeIterator ⓘ;
fn pos(&self) -> IVec2;
fn set_pos(&mut self, pos: IVec2);
fn bounds(&self) -> GridRect;
}Expand description
A trait for accessing the points of shapes on a grid.
Required Methods
Sourcefn iter(&self) -> GridShapeIterator ⓘ
fn iter(&self) -> GridShapeIterator ⓘ
Iterate over all the points contained within the grid shape.